@@ -1,5 +1,5 @@
 __author__ = "Vanessa Sochat"
-__copyright__ = "Copyright 2021, Vanessa Sochat"
+__copyright__ = "Copyright 2021-2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 from shpc.main.client import Client as BaseClient
@@ -11,6 +11,7 @@ from jinja2 import Template
 
 from datetime import datetime
 import os
+from pathlib import Path
 import shutil
 import subprocess
 import sys
@@ -145,7 +146,8 @@ class ModuleBase(BaseClient):
         """
         module_name = self.add_namespace(module_name)
         template = self._load_template(self.templatefile)
-        self.container.add(sif, module_name, self.modulefile, template, **kwargs)
+        modulefile = os.path.join(self.settings.module_base, module_name.replace(":", os.sep), self.modulefile)
+        self.container.add(sif, module_name, modulefile, template, **kwargs)
 
     def get(self, module_name, env_file=False):
         """
@@ -292,8 +294,8 @@ class ModuleBase(BaseClient):
                 % (name, "\n".join(config.tags.keys()))
             )
 
-        # We currently support gh or docker
-        uri = getattr(config, "docker") or getattr(config, "gh")
+        # We currently support gh, docker, or oras
+        uri = config.get_uri()
 
         # This is a tag object with name and digest
         tag = config.tag
@@ -304,6 +306,13 @@ class ModuleBase(BaseClient):
         container_dir = self.container.container_dir(subfolder)
         shpc.utils.mkdirp([module_dir, container_dir])
 
+        # Add a .version file to indicate the level of versioning (not for tcl)
+        if self.module_extension != "tcl" and self.settings.default_version == True:
+            version_dir = os.path.join(self.settings.module_base, uri)
+            version_file = os.path.join(version_dir, ".version")
+            if not os.path.exists(version_file):
+                Path(version_file).touch()
+
         # For Singularity this is a path, podman is a uri. If None is returned
         # there was an error and we cleanup
         container_path = self.container.registry_pull(
