@@ -1,11 +1,11 @@
 __author__ = "Vanessa Sochat"
-__copyright__ = "Copyright 2021, Vanessa Sochat"
+__copyright__ = "Copyright 2021-2022, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 
 ## ContainerConfig Schema
 
-schema_url = "https://json-schema.org/draft-07/schema/#"
+schema_url = "http://json-schema.org/draft-07/schema"
 
 # This is also for latest, and a list of tags
 
@@ -69,6 +69,7 @@ latest = {
 containerConfigProperties = {
     "latest": aliases,
     "docker": {"type": "string"},
+    "oras": {"type": "string"},
     "gh": {"type": "string"},
     "url": {"type": "string"},
     "test": {"type": "string"},
@@ -122,6 +123,7 @@ settingsProperties = {
     "module_name": {"type": "string"},
     "config_editor": {"type": "string"},
     "environment_file": {"type": "string"},
+    "default_version": {"type": "boolean"},
     "enable_tty": {"type": "boolean"},
     "container_tech": {"type": "string", "enum": ["singularity", "podman", "docker"]},
     "singularity_shell": {"type": "string", "enum": shells},
