@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# Copyright (C) 2021 Vanessa Sochat.
+# Copyright (C) 2021-2022 Vanessa Sochat.
 
 # This Source Code Form is subject to the terms of the
 # Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
@@ -31,6 +31,15 @@ def test_pull_gh(tmp_path):
     assert os.path.exists(result)
 
 
+def test_pull_oras(tmp_path):
+    cli = container.SingularityContainer()
+
+    # Test default Singularity pull
+    image = os.path.join(str(tmp_path), "container.sif")
+    result = cli.pull("oras://ghcr.io/singularityhub/github-ci:latest", image)
+    assert os.path.exists(result)
+
+
 def test_podman(tmp_path):
     """Test a singularity container command"""
     cli = container.PodmanContainer()
